==> hoteldruid-mod-bg_2.2.0-1.zip: bg/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "Фамилното име ще бъде сменено от"; break;
case "a":  					$messaggio = "на"; break;
case "Il nome verrà cambiato da":  		$messaggio = "Името ще бъде сменено от"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "Полът ще бъде сменен на "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "Рожденният ден ще бъде сменен от"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "Телефонният номер ще бъде сменен от"; break;
case "La via  verrà cambiata da":  		$messaggio = "Улицата ще бъде сменена от"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "Номерът на улицата ще бъде сменен от"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "Градът по местоживеене ще бъде сменен от"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "Националноста по местоживеене ще бъде сменена от"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "Пощенският код ще бъде сменен от"; break;
case "Il fax verrà cambiato da":  		$messaggio = "Факсът ще бъде сменен от"; break;
case "L' email verrà cambiata da":  		$messaggio = "Ел. пощата ще бъде сменена от"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "Вторият телефон ще бъде сменен от"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "Третият телефон ще бъде сменен от"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "<b>Коментарът</b> ще бъде променен"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "<b>Името</b> ще бъде изтрито"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "<b>Рожденният ден</b> ще бъде изтрит"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "<b>Телефонът</b> ще бъде изтрит"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "<b>Улицата </b>ще бъде изтрита"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "<b>Номерът на улицата</b>  ще бъде изтрит"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "<b>Градът по местоживеене</b> ще бъде изтрит"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "<b>Нацията по местоживеене</b> ще бъде изтрита"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "<b>Пощенският код</b> ще бъде изтрит"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "<b>Факсът</b> ще бъде изтрит"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "<b>Ел. пощата</b> ще бъде изтрита"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "<b>Вторият телефон</b> ще бъде изтрит"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "<b>Третият телефон</b> ще бъде изтрит"; break;
case "Continua":  				$messaggio = "Продължете"; break;
case "Il cliente":  				$messaggio = "Клиентът"; break;
case "è stato modificato":  			$messaggio = "беше променен"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "Modifica i dati del cliente":  		$messaggio = "Променете данните за клиент"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "cambia in":  				$messaggio = "променете на"; break;
case "Nome":  					$messaggio = "Име"; break;
case "cancella":  				$messaggio = "изтриване"; break;
case "Sesso":  					$messaggio = "Пол"; break;
case "Data di nascita":  			$messaggio = "Рожден ден"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "Via":  					$messaggio = "Ул."; break;
case "Piazza":  				$messaggio = "Пл."; break;
case "Viale":  					$messaggio = "Аве."; break;
case "Piazzale":  				$messaggio = "Бул."; break;
case "Vicolo":  				$messaggio = "Път"; break;
case "Numero civico":  				$messaggio = "ЕГН"; break;
case "Città di residenza":  			$messaggio = "Град по местоживеене"; break;
case "Nazione di residenza":  			$messaggio = "Националност по местоживеене"; break;
case "CAP":  					$messaggio = "Пощенски код"; break;
case "Fax":  					$messaggio = "Факс"; break;
case "Email":  					$messaggio = "Ел. поща"; break;
case "2° telefono":  				$messaggio = "Втори телефон"; break;
case "3° telefono":  				$messaggio = "Трети телефон"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "Prenotazioni del cliente":  		$messaggio = "Резервации на клиент"; break;
case "nel":  					$messaggio = "през"; break;
case "Cognome_del_cliente":  			$messaggio = "Фамилия"; break;
case "Data_iniziale":  				$messaggio = "Пристигане"; break;
case "Data_finale":  				$messaggio = "Заминаване"; break;
case "Tariffa_completa":  			$messaggio = "Общо за плащане"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "Pagato":  				$messaggio = "Платено"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "TOTALE":  				$messaggio = "ОБЩО"; break;
case "Pers":  					$messaggio = "Души"; break;
case "Inserito da":  				$messaggio = "Въведено от"; break;
case "Si considererà l'utente":  		$messaggio = "Потребител"; break;
case "come colui che ha inserito il cliente":	$messaggio = "ще бъде считан за този, който е въвел клиента"; break;
case "Cliente cancellato":  			$messaggio = "Клиентът е изтрит"; break;
case "Cancella il cliente":  			$messaggio = "Изтрийте клиент"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Този клиент не може да бъде изтрит защото той е все още свързан с някои резервации"; break;
case "NO":  					$messaggio = "НЕ"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Сигурни ли сте, че искате да <div style=\"display: inline; color: red;\">изтриете</div> клиент"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Област по местоживеене"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "Scadenza documento":  			$messaggio = "Документът изтича на"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "Областта по местоживеене ще бъде променена от"; break;
case "Il documento verrà cambiato da":  	$messaggio = "Документът ще бъде променен от"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "Датата на изтичане на документа ще бъде променена от"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "<b>Областта по местоживеене</b> ще бъде изтрита"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "<b>Документът</b> ще бъде изтрит"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "<b>Датата на изтичане на документа</b> ще бъде изтрита"; break;
case "Cittadinanza":  				$messaggio = "Националност"; break;
case "Nazione di nascita":  			$messaggio = "Националност по рождение"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Област по рождение"; break;
case "Città di nascita":  			$messaggio = "Град по рождение"; break;
case "Nazione di rilascio":  			$messaggio = "Издаден от държава"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "Националността ще бъде променена от"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "Националността по рождение ще бъде променена от"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "Областта по рождение ще бъде променена от"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "Градът по рождение ще бъде променен от"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "Държавата издала документа ще бъде променена от"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "<b>Националността</b> ще бъде изтрита"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "<b>Националността по рождение</b> ще бъде изтрита"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "<b>Областта по рождение</b> ще бъде изтрита"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "<b>Градът по рождение</b> ще бъде изтрита"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "<b>Държавата издала документа</b> ще бъде изтрита"; break;
case "Codice fiscale":  			$messaggio = "Фискален код"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "Фискалният код ще бъде променен от"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "<b>Фискалният код</b> ще бъде изтрит"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Città di rilascio":  			$messaggio = "Releasing city"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Releasing region"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "The city releasing the document will be changed from"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "The region releasing the document will be changed from"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>city releasing the document</b> will be deleted"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>region releasing the document</b> will be deleted"; break;
case "Titolo":  				$messaggio = "Title"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "The title will be changed from"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "The <b>title</b> will be deleted"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-bg_3.0.8-1.zip: bg/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "Фамилното име ще бъде сменено от"; break;
case "a":  					$messaggio = "на"; break;
case "Il nome verrà cambiato da":  		$messaggio = "Името ще бъде сменено от"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "Полът ще бъде сменен на "; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "Рожденният ден ще бъде сменен от"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "Телефонният номер ще бъде сменен от"; break;
case "La via  verrà cambiata da":  		$messaggio = "Улицата ще бъде сменена от"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "Номерът на улицата ще бъде сменен от"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "Градът по местоживеене ще бъде сменен от"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "Националноста по местоживеене ще бъде сменена от"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "Пощенският код ще бъде сменен от"; break;
case "Il fax verrà cambiato da":  		$messaggio = "Факсът ще бъде сменен от"; break;
case "L' email verrà cambiata da":  		$messaggio = "Ел. пощата ще бъде сменена от"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "Вторият телефон ще бъде сменен от"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "Третият телефон ще бъде сменен от"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "<b>Коментарът</b> ще бъде променен"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "<b>Името</b> ще бъде изтрито"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "<b>Рожденният ден</b> ще бъде изтрит"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "<b>Телефонът</b> ще бъде изтрит"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "<b>Улицата </b>ще бъде изтрита"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "<b>Номерът на улицата</b>  ще бъде изтрит"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "<b>Градът по местоживеене</b> ще бъде изтрит"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "<b>Нацията по местоживеене</b> ще бъде изтрита"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "<b>Пощенският код</b> ще бъде изтрит"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "<b>Факсът</b> ще бъде изтрит"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "<b>Ел. пощата</b> ще бъде изтрита"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "<b>Вторият телефон</b> ще бъде изтрит"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "<b>Третият телефон</b> ще бъде изтрит"; break;
case "Continua":  				$messaggio = "Продължете"; break;
case "Il cliente":  				$messaggio = "Клиентът"; break;
case "è stato modificato":  			$messaggio = "беше променен"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "Modifica i dati del cliente":  		$messaggio = "Променете данните за клиент"; break;
case "Cognome":  				$messaggio = "Фамилия"; break;
case "cambia in":  				$messaggio = "променете на"; break;
case "Nome":  					$messaggio = "Име"; break;
case "cancella":  				$messaggio = "изтриване"; break;
case "Sesso":  					$messaggio = "Пол"; break;
case "Data di nascita":  			$messaggio = "Рожден ден"; break;
case "Telefono":  				$messaggio = "Телефон"; break;
case "Via":  					$messaggio = "Ул."; break;
case "Piazza":  				$messaggio = "Пл."; break;
case "Viale":  					$messaggio = "Аве."; break;
case "Piazzale":  				$messaggio = "Бул."; break;
case "Vicolo":  				$messaggio = "Път"; break;
case "Numero civico":  				$messaggio = "ЕГН"; break;
case "Città di residenza":  			$messaggio = "Град по местоживеене"; break;
case "Nazione di residenza":  			$messaggio = "Националност по местоживеене"; break;
case "CAP":  					$messaggio = "Пощенски код"; break;
case "Fax":  					$messaggio = "Факс"; break;
case "Email":  					$messaggio = "Ел. поща"; break;
case "2° telefono":  				$messaggio = "Втори телефон"; break;
case "3° telefono":  				$messaggio = "Трети телефон"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "Prenotazioni del cliente":  		$messaggio = "Резервации на клиент"; break;
case "nel":  					$messaggio = "през"; break;
case "Cognome_del_cliente":  			$messaggio = "Фамилия"; break;
case "Data_iniziale":  				$messaggio = "Пристигане"; break;
case "Data_finale":  				$messaggio = "Заминаване"; break;
case "Tariffa_completa":  			$messaggio = "Общо за плащане"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "Pagato":  				$messaggio = "Платено"; break;
case "Commento":  				$messaggio = "Коментар"; break;
case "TOTALE":  				$messaggio = "ОБЩО"; break;
case "Pers":  					$messaggio = "Души"; break;
case "Inserito da":  				$messaggio = "Въведено от"; break;
case "Si considererà l'utente":  		$messaggio = "Потребител"; break;
case "come colui che ha inserito il cliente":	$messaggio = "ще бъде считан за този, който е въвел клиента"; break;
case "Cliente cancellato":  			$messaggio = "Клиентът е изтрит"; break;
case "Cancella il cliente":  			$messaggio = "Изтрийте клиент"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Този клиент не може да бъде изтрит защото той е все още свързан с някои резервации"; break;
case "NO":  					$messaggio = "НЕ"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "Сигурни ли сте, че искате да <div style=\"display: inline; color: red;\">изтриете</div> клиент"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Област по местоживеене"; break;
case "Documento":  				$messaggio = "Документ"; break;
case "Scadenza documento":  			$messaggio = "Документът изтича на"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "Областта по местоживеене ще бъде променена от"; break;
case "Il documento verrà cambiato da":  	$messaggio = "Документът ще бъде променен от"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "Датата на изтичане на документа ще бъде променена от"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "<b>Областта по местоживеене</b> ще бъде изтрита"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "<b>Документът</b> ще бъде изтрит"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "<b>Датата на изтичане на документа</b> ще бъде изтрита"; break;
case "Cittadinanza":  				$messaggio = "Националност"; break;
case "Nazione di nascita":  			$messaggio = "Националност по рождение"; break;
case "Reg./Prov. di nascita":  			$messaggio = "Област по рождение"; break;
case "Città di nascita":  			$messaggio = "Град по рождение"; break;
case "Nazione di rilascio":  			$messaggio = "Издаден от държава"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "Националността ще бъде променена от"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "Националността по рождение ще бъде променена от"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "Областта по рождение ще бъде променена от"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "Градът по рождение ще бъде променен от"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "Държавата издала документа ще бъде променена от"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "<b>Националността</b> ще бъде изтрита"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "<b>Националността по рождение</b> ще бъде изтрита"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "<b>Областта по рождение</b> ще бъде изтрита"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "<b>Градът по рождение</b> ще бъде изтрита"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "<b>Държавата издала документа</b> ще бъде изтрита"; break;
case "Codice fiscale":  			$messaggio = "Фискален код"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "Фискалният код ще бъде променен от"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "<b>Фискалният код</b> ще бъде изтрит"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Città di rilascio":  			$messaggio = "Releasing city"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Releasing region"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "The city releasing the document will be changed from"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "The region releasing the document will be changed from"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>city releasing the document</b> will be deleted"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "The <b>region releasing the document</b> will be deleted"; break;
case "Titolo":  				$messaggio = "Title"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "The title will be changed from"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "The <b>title</b> will be deleted"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
case "2° cognome":  				$messaggio = "2nd surname"; break;
case "Il 2° cognome verrà cambiato da":  	$messaggio = "The 2nd surname will be changed from"; break;
case "Il <b>2° cognome</b> verrà cancellato":	$messaggio = "The <b>2nd surname</b> will be deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
